//! API representation of user information
//!
//! @author Pierre Hubert
use serde::Serialize;

use crate::data::user::{User, UserPageStatus, UserID};

#[derive(Serialize)]
#[allow(non_snake_case)]
pub struct APIUserInfo {
    userID: i64,
    firstName: String,
    lastName: String,
    publicPage: bool,
    openPage: bool,
    virtualDirectory: String,
    accountImage: String,
}

impl APIUserInfo {
    /// Construct a new API user instance. Note: `user_id` is the ID of the user who makes the
    /// requests, not the user whose we return information about!
    pub fn new(user_id: Option<UserID>, info: &User) -> APIUserInfo {
        APIUserInfo {
            userID: info.id,
            firstName: info.first_name.to_string(),
            lastName: info.last_name.to_string(),
            publicPage: info.status != UserPageStatus::PRIVATE,
            openPage: info.status == UserPageStatus::OPEN,
            virtualDirectory: info.virtual_directory.clone().unwrap_or(String::new()),
            accountImage: APIUserInfo::get_account_image_url(user_id, info),
        }
    }

    /// Get the URL of a specific user account image
    pub fn get_account_image_url(user_id: Option<UserID>, user: &User) -> String {
        "do it".to_string()
    }
}